@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.867';
+our $VERSION = '1.868';
 
 use base 'MCE::Mutex';
 use Scalar::Util qw(refaddr weaken);
@@ -84,7 +84,7 @@ sub new {
 }
 
 sub lock {
-    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
     MCE::Util::_sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
@@ -96,27 +96,29 @@ sub lock {
 *lock_shared    = \&lock;
 
 sub unlock {
-    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
-    syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0
+    CORE::syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0
         if $obj->{ $pid };
 
     return;
 }
 
 sub synchronize {
-    my ($pid, $obj, $code, @ret) = ($tid ? $$ .'.'. $tid : $$, shift, shift);
+    my ($pid, $obj, $code) = ($tid ? $$ .'.'. $tid : $$, shift, shift);
+    my (@ret, $b);
+
     return unless ref($code) eq 'CODE';
 
     # lock, run, unlock - inlined for performance
-    MCE::Util::_sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
+    MCE::Util::_sysread($obj->{_r_sock}, $b, 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
 
     (defined wantarray)
       ? @ret = wantarray ? $code->(@_) : scalar $code->(@_)
       : $code->(@_);
 
-    syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0;
+    CORE::syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0;
 
     return wantarray ? @ret : $ret[-1];
 }
@@ -139,7 +141,7 @@ MCE::Mutex::Channel - Mutex locking via a pipe or socket
 
 =head1 VERSION
 
-This document describes MCE::Mutex::Channel version 1.867
+This document describes MCE::Mutex::Channel version 1.868
 
 =head1 DESCRIPTION
 
